pub fn resolve_auth_for_provider(
provider: LlmProvider,
) -> Result<AuthSource, ApiError>Expand description
Read the standard env var for provider and return the appropriate auth.
pub fn resolve_auth_for_provider(
provider: LlmProvider,
) -> Result<AuthSource, ApiError>Read the standard env var for provider and return the appropriate auth.